/*
 * File:  BootMain.c
 */
//*****************************************************************************


#include <stdint.h>
#include <stdbool.h>
#include "inc/hw_memmap.h"
#include "driverlib/sysctl.h"
#include "driverlib/gpio.h"
#include "driverlib/interrupt.h"
#include <LxiBootUsb.h>
#include "console.h"    // Has InitConsole(void) function for UART 0.
#include "inc/hw_ints.h"
#include "inc/hw_types.h"
#include "driverlib/systick.h"


#define     NUM_SYSTICKS_PER_SECOND     1000

volatile uint32_t tickCount           = 0;

void       isr_1ms( )
{
    tickCount++;
}




void InitGPIOPins( )
{
    // Enable power supplies.
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOF);
    GPIODirModeSet(GPIO_PORTF_BASE, GPIO_PIN_2 | GPIO_PIN_3, GPIO_DIR_MODE_OUT);
    GPIOPadConfigSet(GPIO_PORTF_BASE, GPIO_PIN_2 | GPIO_PIN_3, GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD);

    GPIOPinWrite(GPIO_PORTA_BASE, GPIO_PIN_7, GPIO_PIN_7);
    // On the Launchpad, this turns on the blue LED.
    GPIOPinWrite(GPIO_PORTF_BASE, GPIO_PIN_3, GPIO_PIN_3);
    // On the Launchpad, this turns on the green LED.

    // Onboard USB hub:  Hold low (not in reset).
    SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOB);
    GPIODirModeSet(GPIO_PORTB_BASE, GPIO_PIN_2, GPIO_DIR_MODE_OUT);
    GPIOPadConfigSet(GPIO_PORTB_BASE, GPIO_PIN_2, GPIO_STRENGTH_4MA, GPIO_PIN_TYPE_STD);
    GPIOPinWrite(GPIO_PORTB_BASE, GPIO_PIN_2, 0);   // Low.  Not in reset.
}



int
main(void)
{
    InitConsole();
    CONOUT(RESETATTR BGBLUE WHITE "\nSparkLXi3  BOOT LOADER starting.\n" RESETATTR);


    // Set the clocking to run from the PLL at 50MHz.
    SysCtlClockSet(SYSCTL_SYSDIV_4 | SYSCTL_USE_PLL | SYSCTL_OSC_MAIN | SYSCTL_XTAL_24MHZ);


    IntMasterDisable();
    InitGPIOPins();

    // Start 1KHz systick interrupt.
    SysTickIntDisable();                // Disable the interrupt.
    IntPendClear(FAULT_SYSTICK);        // Clear any leftover pending interrupt.
    SysTickPeriodSet(SysCtlClockGet() / NUM_SYSTICKS_PER_SECOND);
    SysTickEnable();                    // Enable SysTick.
    SysTickIntEnable();                 // Enable the SysTick Interrupt.

    IntMasterEnable();

    SysCtlDelay(SysCtlClockGet() / 30);     // 1/10 sec.  Time is 3*param.
    if (tickCount < 95) {
        //ABORT("Timer ISR not running.");
        CONOUT("Timer ISR not running.");
        SysCtlReset();      //Hack.  Still haven't fixed systick failure problem.
    }


    // Priority:  Only upper 3 bits (of byte) used, e.g. 0x20,40,60,...
    IntPrioritySet(FAULT_SYSTICK, 0);
    IntPrioritySet(INT_UART0, 0x40);
    IntPrioritySet(INT_USB0, 0x60);
    // The UART priority must be set higher than USB priority, otherwise UART debug
    // output will hang when called from a USB interrupt context.

    // Init LXi USB support
    SysCtlPeripheralPowerOn(SYSCTL_PERIPH_USB0);
    SysCtlPeripheralEnable(SYSCTL_PERIPH_USB0);
    while (!SysCtlPeripheralReady(SYSCTL_PERIPH_USB0));
    SysCtlPeripheralReset(SYSCTL_PERIPH_USB0);
    while (!SysCtlPeripheralReady(SYSCTL_PERIPH_USB0));
    LxiUsbInit( );


    // Main loop
    while(1)
    {
        LxiUsbPoll( );
    }
}




#ifdef DEBUG
void
__error__(char *pcFilename, uint32_t ui32Line)
{
    UARTprintf("ASSERT ERROR at line %d of file %s\nHalting.\n", ui32Line, pcFilename);
    volatile int x=1;
    while(x);   // In debugger, change x to 0 to return to calling function.
}
#endif

