/*
 * console.c
 *
 *  Created on: Feb 8, 2022
 *      Author: dkaden
 */


#include "stdint.h"
#include "stdbool.h"
#include "inc/hw_memmap.h"
#include "driverlib/sysctl.h"
#include "utils/uartstdio.h"
#include "driverlib/gpio.h"
#include "driverlib/pin_map.h"
#include "driverlib/uart.h"
#include <console.h>

//*****************************************************************************
//
// This function sets up UART0 to be used for a console to display information
// as the example is running.
//
//*****************************************************************************

void
InitConsole(void)
{
	// Enable GPIO port A which is used for UART0 pins.
	// TODO: change this to whichever GPIO port you are using.
	//
	SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA);

	// Configure the pin muxing for UART0 functions on port A0 and A1.
	// This step is not necessary if your part does not support pin muxing.
	// TODO: change this to select the port/pin you are using.
	//
	GPIOPinConfigure(GPIO_PA0_U0RX);
	GPIOPinConfigure(GPIO_PA1_U0TX);

	// Enable UART0 so that we can configure the clock.
	//
	SysCtlPeripheralEnable(SYSCTL_PERIPH_UART0);

	// Use the internal 16MHz oscillator as the UART clock source.
	//
	UARTClockSourceSet(UART0_BASE, UART_CLOCK_PIOSC);

	// Select the alternate (UART) function for these pins.
	// TODO: change this to select the port/pin you are using.
	//
	GPIOPinTypeUART(GPIO_PORTA_BASE, GPIO_PIN_0 | GPIO_PIN_1);

	// Initialize the UART for console I/O.
	//
	UARTStdioConfig(0, 115200, 16000000);

#ifdef UART_BUFFERED
	// This is to prevent the key pressed during PAUSE from displaying.
	UARTEchoSet(false);
#endif
}



void debugout(const char *msg, ...)
{
	va_list vl;
	va_start (vl, msg);
	UARTvprintf(msg, vl);
}


#ifdef DEBUG

static char digit[] = {'0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F'};

void UartHexOutB(uint8_t val)
{
    const char  mask = 0xF;
    UARTCharPut(UART0_BASE, digit[val >> 4]);
    UARTCharPut(UART0_BASE, digit[val & mask]);
}

void UartHexOutW(uint16_t val)
{
    const char  mask = 0xF;
    int         i;
    char        digits[4];

    for (i=3;i>=0;--i) {
        digits[i] =digit[val & mask];
        val >>= 4;
    }
    for (i=0;i<4;++i)
        UARTCharPut(UART0_BASE, digits[i]);
}

#endif  // ifdef DEBUG
